@@ -4,25 +4,21 @@ from os.path import basename
 
 from integration_tests.test_cfngin.test_cfngin import Cfngin
 
-FILE_BASENAME = '.'.join(basename(__file__).split('.')[:-1])
+FILE_BASENAME = ".".join(basename(__file__).split(".")[:-1])
 
 
 class TestEmptyConfig(Cfngin):
     """Test CFNgin with an empty config file."""
 
-    REQUIRED_FIXTURE_FILES = [
-        FILE_BASENAME + '.yaml'
-    ]
+    REQUIRED_FIXTURE_FILES = [FILE_BASENAME + ".yaml"]
     TEST_NAME = __name__
 
     def run(self):
         """Run the test."""
         self.copy_fixtures()
-        code, _stdout, stderr = self.runway_cmd('deploy')
-        assert code != 0, 'exit could should be non-zero'
-        expected_lines = [
-            'runway.cfngin.exceptions.InvalidConfig'
-        ]
+        code, _stdout, stderr = self.runway_cmd("deploy")
+        assert code != 0, "exit could should be non-zero"
+        expected_lines = ["runway.cfngin.exceptions.InvalidConfig"]
         for line in expected_lines:
             assert line in stderr, f'"{line}" missing from output'
 
