@@ -1,4 +1,4 @@
 """Import modules."""
 import numpy as np
 
-RESPONSE_OBJ = np.arange('15').reshape(3, 5)
+RESPONSE_OBJ = np.arange("15").reshape(3, 5)
