@@ -21,30 +21,31 @@ from runway.cfngin.blueprints.variables.types import (
 
 
 class FunctionalTests(Blueprint):
-    """This creates a stack with an IAM user and access key for running the
-    functional tests for stacker.
-    """
+    """Stack with an IAM user and access key for running functional tests."""
 
     VARIABLES = {
         "StackerNamespace": {
             "type": CFNString,
             "description": "The stacker namespace that the tests will use. "
-                           "Access to cloudformation will be restricted to "
-                           "only allow access to stacks with this prefix."},
+            "Access to cloudformation will be restricted to "
+            "only allow access to stacks with this prefix.",
+        },
         "StackerBucket": {
             "type": CFNString,
             "description": "The name of the bucket that the tests will use "
-                           "for uploading templates."}
+            "for uploading templates.",
+        },
     }
 
     def create_template(self):
+        """Create template."""
         t = self.template
 
         bucket_arn = Sub("arn:aws:s3:::${StackerBucket}*")
         objects_arn = Sub("arn:aws:s3:::${StackerBucket}*/*")
         cloudformation_scope = Sub(
-            "arn:aws:cloudformation:*:${AWS::AccountId}:"
-            "stack/${StackerNamespace}-*")
+            "arn:aws:cloudformation:*:${AWS::AccountId}:" "stack/${StackerNamespace}-*"
+        )
         changeset_scope = "*"
 
         # This represents the precise IAM permissions that stacker itself
@@ -56,7 +57,7 @@ class FunctionalTests(Blueprint):
                     Statement(
                         Effect="Allow",
                         Resource=["*"],
-                        Action=[awacs.s3.ListAllMyBuckets]
+                        Action=[awacs.s3.ListAllMyBuckets],
                     ),
                     Statement(
                         Effect="Allow",
@@ -66,7 +67,7 @@ class FunctionalTests(Blueprint):
                             awacs.s3.GetBucketLocation,
                             awacs.s3.CreateBucket,
                             awacs.s3.DeleteBucket,
-                        ]
+                        ],
                     ),
                     Statement(
                         Effect="Allow",
@@ -76,14 +77,12 @@ class FunctionalTests(Blueprint):
                             awacs.s3.GetObjectAcl,
                             awacs.s3.PutObject,
                             awacs.s3.PutObjectAcl,
-                        ]
+                        ],
                     ),
                     Statement(
                         Effect="Allow",
                         Resource=[objects_arn],
-                        Action=[
-                            awacs.s3.DeleteObject,
-                        ]
+                        Action=[awacs.s3.DeleteObject],
                     ),
                     Statement(
                         Effect="Allow",
@@ -92,12 +91,12 @@ class FunctionalTests(Blueprint):
                             awacs.cloudformation.DescribeChangeSet,
                             awacs.cloudformation.ExecuteChangeSet,
                             awacs.cloudformation.DeleteChangeSet,
-                        ]
+                        ],
                     ),
                     Statement(
                         Effect="Deny",
                         Resource=[Ref("AWS::StackId")],
-                        Action=[awacs.cloudformation.Action("*")]
+                        Action=[awacs.cloudformation.Action("*")],
                     ),
                     Statement(
                         Effect="Allow",
@@ -111,11 +110,11 @@ class FunctionalTests(Blueprint):
                             awacs.cloudformation.UpdateStack,
                             awacs.cloudformation.SetStackPolicy,
                             awacs.cloudformation.DescribeStacks,
-                            awacs.cloudformation.DescribeStackEvents
-                        ]
-                    )
+                            awacs.cloudformation.DescribeStackEvents,
+                        ],
+                    ),
                 ]
-            )
+            ),
         )
 
         principal = AWSPrincipal(Ref("AWS::AccountId"))
@@ -126,11 +125,14 @@ class FunctionalTests(Blueprint):
                     Statement=[
                         Statement(
                             Effect="Allow",
-                            Action=[
-                                awacs.sts.AssumeRole],
-                            Principal=principal)]),
-                Policies=[
-                    stacker_policy]))
+                            Action=[awacs.sts.AssumeRole],
+                            Principal=principal,
+                        )
+                    ]
+                ),
+                Policies=[stacker_policy],
+            )
+        )
 
         assumerole_policy = iam.Policy(
             PolicyName="AssumeRole",
@@ -139,70 +141,66 @@ class FunctionalTests(Blueprint):
                     Statement(
                         Effect="Allow",
                         Resource=[GetAtt(role, "Arn")],
-                        Action=[
-                            awacs.sts.AssumeRole])]))
+                        Action=[awacs.sts.AssumeRole],
+                    )
+                ]
+            ),
+        )
 
         user = t.add_resource(
-            iam.User(
-                "FunctionalTestUser",
-                Policies=[
-                    stacker_policy,
-                    assumerole_policy]))
+            iam.User("FunctionalTestUser", Policies=[stacker_policy, assumerole_policy])
+        )
 
         key = t.add_resource(
-            iam.AccessKey(
-                "FunctionalTestKey",
-                Serial=1,
-                UserName=Ref(user)))
+            iam.AccessKey("FunctionalTestKey", Serial=1, UserName=Ref(user))
+        )
 
         t.add_output(Output("User", Value=Ref(user)))
         t.add_output(Output("AccessKeyId", Value=Ref(key)))
         t.add_output(
             Output(
-                "SecretAccessKey",
-                Value=GetAtt("FunctionalTestKey", "SecretAccessKey")))
-        t.add_output(
-            Output(
-                "FunctionalTestRole",
-                Value=GetAtt(role, "Arn")))
+                "SecretAccessKey", Value=GetAtt("FunctionalTestKey", "SecretAccessKey")
+            )
+        )
+        t.add_output(Output("FunctionalTestRole", Value=GetAtt(role, "Arn")))
 
 
 class Dummy(Blueprint):
-    VARIABLES = {
-        "StringVariable": {
-            "type": str,
-            "default": ""}
-    }
+    """Dummy."""
+
+    VARIABLES = {"StringVariable": {"type": str, "default": ""}}
 
     def create_template(self):
+        """Create template."""
         self.template.add_resource(WaitConditionHandle("Dummy"))
         self.template.add_output(Output("DummyId", Value="dummy-1234"))
         self.template.add_output(Output("Region", Value=Ref("AWS::Region")))
 
 
 class Dummy2(Blueprint):
-    """
-    This blueprint allows tests of only additional resources to occur.
+    """Allows tests of only additional resources to occur.
+
     Just swap out the Dummy class for Dummy2 on the same stack.
+
     """
-    VARIABLES = {
-        "StringVariable": {
-            "type": str,
-            "default": ""}
-    }
+
+    VARIABLES = {"StringVariable": {"type": str, "default": ""}}
 
     def create_template(self):
+        """Create template."""
         self.template.add_resource(WaitConditionHandle("Dummy"))
         self.template.add_output(Output("DummyId", Value="dummy-1234"))
         self.template.add_resource(WaitConditionHandle("Dummy2"))
 
 
 class LongRunningDummy(Blueprint):
+    """Meant to be an attempt to create a cheap, slow blueprint.
+
+    Takes a little bit of time to create/rollback/destroy to avoid some of the
+    race conditions we've seen in some of our functional tests.
+
     """
-    Meant to be an attempt to create a cheap blueprint that takes a little bit
-    of time to create/rollback/destroy to avoid some of the race conditions
-    we've seen in some of our functional tests.
-    """
+
     VARIABLES = {
         "Count": {
             "type": int,
@@ -212,18 +210,18 @@ class LongRunningDummy(Blueprint):
         "BreakLast": {
             "type": bool,
             "description": "Whether or not to break the last WaitConditon "
-                           "by creating an invalid WaitConditionHandle.",
+            "by creating an invalid WaitConditionHandle.",
             "default": True,
         },
         "OutputValue": {
             "type": str,
-            "description": "The value to put in an output to allow for "
-                           "updates.",
+            "description": "The value to put in an output to allow for " "updates.",
             "default": "DefaultOutput",
         },
     }
 
     def create_template(self):
+        """Create template."""
         v = self.get_variables()
         t = self.template
         base_name = "Dummy"
@@ -248,172 +246,216 @@ class LongRunningDummy(Blueprint):
                     Handle=wch.Ref(),
                     # Timeout is made deliberately large so CF rejects it
                     Timeout=2 ** 32,
-                    Count=0
+                    Count=0,
                 )
             )
 
 
 class Broken(Blueprint):
+    """Blueprint that deliberately fails validation.
+
+    It can be used to test re-creation of a failed stack.
+
     """
-    This blueprint deliberately fails validation, so that it can be used to
-    test re-creation of a failed stack
-    """
-    VARIABLES = {
-        "StringVariable": {
-            "type": str,
-            "default": ""}
-    }
+
+    VARIABLES = {"StringVariable": {"type": str, "default": ""}}
 
     def create_template(self):
+        """Create template."""
         t = self.template
         t.add_resource(WaitConditionHandle("BrokenDummy"))
-        t.add_resource(WaitCondition(
-            "BrokenWaitCondition",
-            Handle=Ref("BrokenDummy"),
-            # Timeout is made deliberately large so CF rejects it
-            Timeout=2 ** 32,
-            Count=0))
+        t.add_resource(
+            WaitCondition(
+                "BrokenWaitCondition",
+                Handle=Ref("BrokenDummy"),
+                # Timeout is made deliberately large so CF rejects it
+                Timeout=2 ** 32,
+                Count=0,
+            )
+        )
         t.add_output(Output("DummyId", Value="dummy-1234"))
 
 
 class VPC(Blueprint):
+    """VPC."""
+
     VARIABLES = {
-        "AZCount": {
-            "type": int,
-            "default": 2,
-        },
+        "AZCount": {"type": int, "default": 2},
         "PrivateSubnets": {
             "type": CFNCommaDelimitedList,
             "description": "Comma separated list of subnets to use for "
-                           "non-public hosts. NOTE: Must have as many subnets "
-                           "as AZCount"},
+            "non-public hosts. NOTE: Must have as many subnets "
+            "as AZCount",
+        },
         "PublicSubnets": {
             "type": CFNCommaDelimitedList,
             "description": "Comma separated list of subnets to use for "
-                           "public hosts. NOTE: Must have as many subnets "
-                           "as AZCount"},
+            "public hosts. NOTE: Must have as many subnets "
+            "as AZCount",
+        },
         "InstanceType": {
             "type": CFNString,
             "description": "NAT EC2 instance type.",
-            "default": "m3.medium"},
+            "default": "m3.medium",
+        },
         "BaseDomain": {
             "type": CFNString,
             "default": "",
-            "description": "Base domain for the stack."},
+            "description": "Base domain for the stack.",
+        },
         "InternalDomain": {
             "type": CFNString,
             "default": "",
-            "description": "Internal domain name, if you have one."},
+            "description": "Internal domain name, if you have one.",
+        },
         "CidrBlock": {
             "type": CFNString,
             "description": "Base CIDR block for subnets.",
-            "default": "10.128.0.0/16"},
+            "default": "10.128.0.0/16",
+        },
         "ImageName": {
             "type": CFNString,
             "description": "The image name to use from the AMIMap (usually "
-                           "found in the config file.)",
-            "default": "NAT"},
+            "found in the config file.)",
+            "default": "NAT",
+        },
         "UseNatGateway": {
             "type": CFNString,
             "allowed_values": ["true", "false"],
             "description": "If set to true, will configure a NAT Gateway"
-                           "instead of NAT instances.",
-            "default": "false"},
+            "instead of NAT instances.",
+            "default": "false",
+        },
     }
 
     def create_template(self):
+        """Create template."""
         self.template.add_resource(WaitConditionHandle("VPC"))
 
 
 class DiffTester(Blueprint):
+    """Diff tester."""
+
     VARIABLES = {
         "InstanceType": {
             "type": CFNString,
             "description": "NAT EC2 instance type.",
-            "default": "m3.medium"},
+            "default": "m3.medium",
+        },
         "WaitConditionCount": {
             "type": int,
             "description": "Number of WaitConditionHandle resources "
-                           "to add to the template"}
+            "to add to the template",
+        },
     }
 
     def create_template(self):
+        """Create template."""
         for i in range(self.get_variables()["WaitConditionCount"]):
             self.template.add_resource(WaitConditionHandle("VPC%d" % i))
 
 
 class Bastion(Blueprint):
+    """Bastion."""
+
     VARIABLES = {
         "VpcId": {"type": EC2VPCId, "description": "Vpc Id"},
-        "DefaultSG": {"type": EC2SecurityGroupId,
-                      "description": "Top level security group."},
-        "PublicSubnets": {"type": EC2SubnetIdList,
-                          "description": "Subnets to deploy public "
-                                         "instances in."},
-        "PrivateSubnets": {"type": EC2SubnetIdList,
-                           "description": "Subnets to deploy private "
-                                          "instances in."},
-        "AvailabilityZones": {"type": CFNCommaDelimitedList,
-                              "description": "Availability Zones to deploy "
-                                             "instances in."},
-        "InstanceType": {"type": CFNString,
-                         "description": "EC2 Instance Type",
-                         "default": "m3.medium"},
-        "MinSize": {"type": CFNNumber,
-                    "description": "Minimum # of instances.",
-                    "default": "1"},
-        "MaxSize": {"type": CFNNumber,
-                    "description": "Maximum # of instances.",
-                    "default": "5"},
+        "DefaultSG": {
+            "type": EC2SecurityGroupId,
+            "description": "Top level security group.",
+        },
+        "PublicSubnets": {
+            "type": EC2SubnetIdList,
+            "description": "Subnets to deploy public " "instances in.",
+        },
+        "PrivateSubnets": {
+            "type": EC2SubnetIdList,
+            "description": "Subnets to deploy private " "instances in.",
+        },
+        "AvailabilityZones": {
+            "type": CFNCommaDelimitedList,
+            "description": "Availability Zones to deploy " "instances in.",
+        },
+        "InstanceType": {
+            "type": CFNString,
+            "description": "EC2 Instance Type",
+            "default": "m3.medium",
+        },
+        "MinSize": {
+            "type": CFNNumber,
+            "description": "Minimum # of instances.",
+            "default": "1",
+        },
+        "MaxSize": {
+            "type": CFNNumber,
+            "description": "Maximum # of instances.",
+            "default": "5",
+        },
         "SshKeyName": {"type": EC2KeyPairKeyName},
         "OfficeNetwork": {
             "type": CFNString,
-            "description": "CIDR block allowed to connect to bastion hosts."},
+            "description": "CIDR block allowed to connect to bastion hosts.",
+        },
         "ImageName": {
             "type": CFNString,
             "description": "The image name to use from the AMIMap (usually "
-                           "found in the config file.)",
-            "default": "bastion"},
+            "found in the config file.)",
+            "default": "bastion",
+        },
     }
 
     def create_template(self):
-        return
+        """Create template."""
 
 
 class PreOneOhBastion(Blueprint):
-    """Used to ensure old blueprints won't be usable in 1.0"""
+    """Used to ensure old blueprints won't be usable in 1.0."""
+
     PARAMETERS = {
         "VpcId": {"type": "AWS::EC2::VPC::Id", "description": "Vpc Id"},
-        "DefaultSG": {"type": "AWS::EC2::SecurityGroup::Id",
-                      "description": "Top level security group."},
-        "PublicSubnets": {"type": "List<AWS::EC2::Subnet::Id>",
-                          "description": "Subnets to deploy public "
-                                         "instances in."},
-        "PrivateSubnets": {"type": "List<AWS::EC2::Subnet::Id>",
-                           "description": "Subnets to deploy private "
-                                          "instances in."},
-        "AvailabilityZones": {"type": "CommaDelimitedList",
-                              "description": "Availability Zones to deploy "
-                                             "instances in."},
-        "InstanceType": {"type": "String",
-                         "description": "EC2 Instance Type",
-                         "default": "m3.medium"},
-        "MinSize": {"type": "Number",
-                    "description": "Minimum # of instances.",
-                    "default": "1"},
-        "MaxSize": {"type": "Number",
-                    "description": "Maximum # of instances.",
-                    "default": "5"},
+        "DefaultSG": {
+            "type": "AWS::EC2::SecurityGroup::Id",
+            "description": "Top level security group.",
+        },
+        "PublicSubnets": {
+            "type": "List<AWS::EC2::Subnet::Id>",
+            "description": "Subnets to deploy public " "instances in.",
+        },
+        "PrivateSubnets": {
+            "type": "List<AWS::EC2::Subnet::Id>",
+            "description": "Subnets to deploy private " "instances in.",
+        },
+        "AvailabilityZones": {
+            "type": "CommaDelimitedList",
+            "description": "Availability Zones to deploy " "instances in.",
+        },
+        "InstanceType": {
+            "type": "String",
+            "description": "EC2 Instance Type",
+            "default": "m3.medium",
+        },
+        "MinSize": {
+            "type": "Number",
+            "description": "Minimum # of instances.",
+            "default": "1",
+        },
+        "MaxSize": {
+            "type": "Number",
+            "description": "Maximum # of instances.",
+            "default": "5",
+        },
         "SshKeyName": {"type": "AWS::EC2::KeyPair::KeyName"},
         "OfficeNetwork": {
             "type": "String",
-            "description": "CIDR block allowed to connect to bastion hosts."},
+            "description": "CIDR block allowed to connect to bastion hosts.",
+        },
         "ImageName": {
             "type": "String",
             "description": "The image name to use from the AMIMap (usually "
-                           "found in the config file.)",
-            "default": "bastion"},
+            "found in the config file.)",
+            "default": "bastion",
+        },
     }
 
     def create_template(self):
-        return
+        """Create template."""
