@@ -1,5 +1,4 @@
 """Utility functions for website build/upload."""
-
 import hashlib
 import logging
 import os
@@ -31,7 +30,10 @@ def calculate_hash_of_files(files, root):
         fileobj = os.path.join(root, fname)
         file_hash.update((fname + "\0").encode())
         with open(fileobj, "rb") as filedes:
-            for chunk in iter(lambda: filedes.read(4096), ""):  # noqa pylint: disable=cell-var-from-loop
+            for chunk in iter(
+                lambda: filedes.read(4096),  # noqa pylint: disable=cell-var-from-loop
+                "",
+            ):
                 if not chunk:
                     break
                 file_hash.update(chunk)
@@ -43,16 +45,15 @@ def calculate_hash_of_files(files, root):
 def get_hash_of_files(root_path, directories=None):
     """Generate md5 hash of files."""
     if not directories:
-        directories = [{'path': './'}]
+        directories = [{"path": "./"}]
 
     files_to_hash = []
     for i in directories:
-        ignorer = get_ignorer(os.path.join(root_path, i['path']),
-                              i.get('exclusions'))
+        ignorer = get_ignorer(os.path.join(root_path, i["path"]), i.get("exclusions"))
 
         with change_dir(root_path):
-            for root, dirs, files in os.walk(i['path'], topdown=True):
-                if (root != './') and ignorer.is_ignored(root, True):
+            for root, dirs, files in os.walk(i["path"], topdown=True):
+                if (root != "./") and ignorer.is_ignored(root, True):
                     dirs[:] = []
                     files[:] = []
                 else:
@@ -60,7 +61,7 @@ def get_hash_of_files(root_path, directories=None):
                         filepath = os.path.join(root, filename)
                         if not ignorer.is_ignored(filepath):
                             files_to_hash.append(
-                                filepath[2:] if filepath.startswith('./') else filepath  # noqa
+                                filepath[2:] if filepath.startswith("./") else filepath
                             )
 
     return calculate_hash_of_files(files_to_hash, root_path)
@@ -69,9 +70,9 @@ def get_hash_of_files(root_path, directories=None):
 def get_ignorer(path, additional_exclusions=None):
     """Create ignorer with directory gitignore file."""
     ignorefile = zgitignore.ZgitIgnore()
-    gitignore_file = os.path.join(path, '.gitignore')
+    gitignore_file = os.path.join(path, ".gitignore")
     if os.path.isfile(gitignore_file):
-        with open(gitignore_file, 'r') as fileobj:
+        with open(gitignore_file, "r") as fileobj:
             ignorefile.add_patterns(fileobj.read().splitlines())
 
     if additional_exclusions is not None:
