@@ -10,20 +10,21 @@ LOGGER = logging.getLogger(__name__)
 
 def assumed_role_to_principle(assumed_role_arn):
     """Return role ARN from assumed role ARN."""
-    arn_split = assumed_role_arn.split(':')
-    arn_split[2] = 'iam'
-    base_arn = ':'.join(arn_split[:5]) + ':role/'
-    return base_arn + assumed_role_arn.split('/')[1]
+    arn_split = assumed_role_arn.split(":")
+    arn_split[2] = "iam"
+    base_arn = ":".join(arn_split[:5]) + ":role/"
+    return base_arn + assumed_role_arn.split("/")[1]
 
 
 def get_principal_arn(provider):
     """Return ARN of current session principle."""
     # looking up caller identity
     session = get_session(provider.region)
-    sts_client = session.client('sts')
-    caller_identity_arn = sts_client.get_caller_identity()['Arn']
-    if caller_identity_arn.split(':')[2] == 'iam' and (
-            caller_identity_arn.split(':')[5].startswith('user/')):
+    sts_client = session.client("sts")
+    caller_identity_arn = sts_client.get_caller_identity()["Arn"]
+    if caller_identity_arn.split(":")[2] == "iam" and (
+        caller_identity_arn.split(":")[5].startswith("user/")
+    ):
         return caller_identity_arn  # user arn
     return assumed_role_to_principle(caller_identity_arn)
 
@@ -39,8 +40,8 @@ def generate(provider, context, **kwargs):  # pylint: disable=W0613
     Returns: boolean for whether or not the hook succeeded.
 
     """
-    overlay_path = os.path.join(*kwargs['path'])
-    filename = os.path.join(overlay_path, kwargs['file'])
+    overlay_path = os.path.join(*kwargs["path"])
+    filename = os.path.join(overlay_path, kwargs["file"])
     if os.path.exists(filename):
         LOGGER.info("%s file present; skipping initial creation", filename)
         return True
@@ -48,24 +49,20 @@ def generate(provider, context, **kwargs):  # pylint: disable=W0613
     if not os.path.isdir(overlay_path):
         os.makedirs(overlay_path)
     principal_arn = get_principal_arn(provider)
-    stack_name = kwargs['stack']
+    stack_name = kwargs["stack"]
     node_instancerole_arn = OutputLookup.handle(
-        "%s::NodeInstanceRoleArn" % stack_name,
-        provider=provider,
-        context=context
+        "%s::NodeInstanceRoleArn" % stack_name, provider=provider, context=context
     )
-    with open(os.path.join(os.path.dirname(os.path.realpath(__file__)),
-                           'aws-auth-cm.yaml'), 'r') as stream:
+    with open(
+        os.path.join(os.path.dirname(os.path.realpath(__file__)), "aws-auth-cm.yaml"),
+        "r",
+    ) as stream:
         aws_authmap_template = stream.read()
-    with open(filename, 'w') as out:
+    with open(filename, "w") as out:
         out.write(
             aws_authmap_template.replace(
-                'INSTANCEROLEARNHERE',
-                node_instancerole_arn
-            ).replace(
-                'ORIGINALPRINCIPALARNHERE',
-                principal_arn
-            )
+                "INSTANCEROLEARNHERE", node_instancerole_arn
+            ).replace("ORIGINALPRINCIPALARNHERE", principal_arn)
         )
     return True
 
@@ -83,8 +80,8 @@ def remove(provider, context, **kwargs):  # pylint: disable=W0613
     Returns: boolean for whether or not the hook succeeded.
 
     """
-    overlay_path = os.path.join(*kwargs['path'])
-    filename = os.path.join(overlay_path, kwargs['file'])
+    overlay_path = os.path.join(*kwargs["path"])
+    filename = os.path.join(overlay_path, kwargs["file"])
     if os.path.exists(filename):
         LOGGER.info("Removing %s...", filename)
         os.remove(filename)
