@@ -8,7 +8,7 @@ from typing import Any, Dict  # noqa pylint: disable=W
 from ..._logging import PrefixAdaptor
 from ...tests.handlers.base import TestHandler
 
-TYPE_NAME = 'script'
+TYPE_NAME = "script"
 LOGGER = logging.getLogger(__name__)
 
 
@@ -36,14 +36,14 @@ class ScriptHandler(TestHandler):
         # type: (str, Dict[str, Any]) -> None
         """Perform the actual test."""
         logger = PrefixAdaptor(name, LOGGER)
-        for cmd in args['commands']:
+        for cmd in args["commands"]:
             try:
                 exit_code = subprocess.call(cmd, shell=True)
                 if exit_code != 0:
                     raise ValueError(exit_code)
             except CalledProcessError as err:
-                logger.error('failed to execute command: %s', cmd)
+                logger.error("failed to execute command: %s", cmd)
                 raise err
             except ValueError:
-                logger.error('failed command: %s', cmd)
+                logger.error("failed command: %s", cmd)
                 sys.exit(1)
