@@ -22,9 +22,19 @@ from runway.cfngin.util import (
     yaml_to_ordered_dict,
 )
 
-AWS_REGIONS = ["us-east-1", "cn-north-1", "ap-northeast-1", "eu-west-1",
-               "ap-southeast-1", "ap-southeast-2", "us-west-2", "us-gov-west-1",
-               "us-west-1", "eu-central-1", "sa-east-1"]
+AWS_REGIONS = [
+    "us-east-1",
+    "cn-north-1",
+    "ap-northeast-1",
+    "eu-west-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "us-west-2",
+    "us-gov-west-1",
+    "us-west-1",
+    "eu-central-1",
+    "sa-east-1",
+]
 
 
 def mock_create_cache_directories(self, **kwargs):
@@ -41,11 +51,7 @@ class TestUtil(unittest.TestCase):
 
     def test_cf_safe_name(self):
         """Test cf safe name."""
-        tests = (
-            ("abc-def", "AbcDef"),
-            ("GhI", "GhI"),
-            ("jKlm.noP", "JKlmNoP")
-        )
+        tests = (("abc-def", "AbcDef"), ("GhI", "GhI"), ("jKlm.noP", "JKlmNoP"))
         for test in tests:
             self.assertEqual(cf_safe_name(test[0]), test[1])
 
@@ -64,31 +70,34 @@ class TestUtil(unittest.TestCase):
         """Test merge map."""
         tests = [
             # 2 lists of stacks defined
-            [{'stacks': [{'stack1': {'variables': {'a': 'b'}}}]},
-             {'stacks': [{'stack2': {'variables': {'c': 'd'}}}]},
-             {'stacks': [
-                 {'stack1': {
-                     'variables': {
-                         'a': 'b'}}},
-                 {'stack2': {
-                     'variables': {
-                         'c': 'd'}}}]}],
+            [
+                {"stacks": [{"stack1": {"variables": {"a": "b"}}}]},
+                {"stacks": [{"stack2": {"variables": {"c": "d"}}}]},
+                {
+                    "stacks": [
+                        {"stack1": {"variables": {"a": "b"}}},
+                        {"stack2": {"variables": {"c": "d"}}},
+                    ]
+                },
+            ],
             # A list of stacks combined with a higher precedence dict of stacks
-            [{'stacks': [{'stack1': {'variables': {'a': 'b'}}}]},
-             {'stacks': {'stack2': {'variables': {'c': 'd'}}}},
-             {'stacks': {'stack2': {'variables': {'c': 'd'}}}}],
+            [
+                {"stacks": [{"stack1": {"variables": {"a": "b"}}}]},
+                {"stacks": {"stack2": {"variables": {"c": "d"}}}},
+                {"stacks": {"stack2": {"variables": {"c": "d"}}}},
+            ],
             # 2 dicts of stacks with non-overlapping variables merged
-            [{'stacks': {'stack1': {'variables': {'a': 'b'}}}},
-             {'stacks': {'stack1': {'variables': {'c': 'd'}}}},
-             {'stacks': {
-                 'stack1': {
-                     'variables': {
-                         'a': 'b',
-                         'c': 'd'}}}}],
+            [
+                {"stacks": {"stack1": {"variables": {"a": "b"}}}},
+                {"stacks": {"stack1": {"variables": {"c": "d"}}}},
+                {"stacks": {"stack1": {"variables": {"a": "b", "c": "d"}}}},
+            ],
             # 2 dicts of stacks with overlapping variables merged
-            [{'stacks': {'stack1': {'variables': {'a': 'b'}}}},
-             {'stacks': {'stack1': {'variables': {'a': 'c'}}}},
-             {'stacks': {'stack1': {'variables': {'a': 'c'}}}}],
+            [
+                {"stacks": {"stack1": {"variables": {"a": "b"}}}},
+                {"stacks": {"stack1": {"variables": {"a": "c"}}}},
+                {"stacks": {"stack1": {"variables": {"a": "c"}}}},
+            ],
         ]
         for test in tests:
             self.assertEqual(merge_map(test[0], test[1]), test[2])
@@ -103,8 +112,8 @@ class TestUtil(unittest.TestCase):
             path: foo1.bar1
         """
         config = yaml_to_ordered_dict(raw_config)
-        self.assertEqual(list(config['pre_build'].keys())[0], 'hook2')
-        self.assertEqual(config['pre_build']['hook2']['path'], 'foo.bar')
+        self.assertEqual(list(config["pre_build"].keys())[0], "hook2")
+        self.assertEqual(config["pre_build"]["hook2"]["path"], "foo.bar")
 
     def test_get_client_region(self):
         """Test get client region."""
@@ -116,21 +125,14 @@ class TestUtil(unittest.TestCase):
     def test_get_s3_endpoint(self):
         """Test get s3 endpoint."""
         endpoint_url = "https://example.com"
-        client = boto3.client("s3", region_name="us-east-1",
-                              endpoint_url=endpoint_url)
+        client = boto3.client("s3", region_name="us-east-1", endpoint_url=endpoint_url)
         self.assertEqual(get_s3_endpoint(client), endpoint_url)
 
     def test_s3_bucket_location_constraint(self):
         """Test s3 bucket location constraint."""
-        tests = (
-            ("us-east-1", ""),
-            ("us-west-1", "us-west-1")
-        )
+        tests = (("us-east-1", ""), ("us-west-1", "us-west-1"))
         for region, result in tests:
-            self.assertEqual(
-                s3_bucket_location_constraint(region),
-                result
-            )
+            self.assertEqual(s3_bucket_location_constraint(region), result)
 
     def test_parse_cloudformation_template(self):
         """Test parse cloudformation template."""
@@ -151,86 +153,79 @@ Outputs:
   DummyId:
     Value: dummy-1234"""
         parsed_template = {
-            'AWSTemplateFormatVersion': '2010-09-09',
-            'Outputs': {'DummyId': {'Value': 'dummy-1234'}},
-            'Parameters': {'Param1': {'Type': 'String'}},
-            'Resources': {
-                'Bucket': {'Type': 'AWS::S3::Bucket',
-                           'Properties': {
-                               'BucketName': {
-                                   u'Fn::Join': [
-                                       '-',
-                                       [{u'Ref': u'AWS::StackName'},
-                                        {u'Ref': u'AWS::Region'}]
-                                   ]
-                               }
-                           }}
-            }
+            "AWSTemplateFormatVersion": "2010-09-09",
+            "Outputs": {"DummyId": {"Value": "dummy-1234"}},
+            "Parameters": {"Param1": {"Type": "String"}},
+            "Resources": {
+                "Bucket": {
+                    "Type": "AWS::S3::Bucket",
+                    "Properties": {
+                        "BucketName": {
+                            u"Fn::Join": [
+                                "-",
+                                [{u"Ref": u"AWS::StackName"}, {u"Ref": u"AWS::Region"}],
+                            ]
+                        }
+                    },
+                }
+            },
         }
-        self.assertEqual(
-            parse_cloudformation_template(template),
-            parsed_template
-        )
+        self.assertEqual(parse_cloudformation_template(template), parsed_template)
 
     def test_extractors(self):
         """Test extractors."""
-        self.assertEqual(Extractor('test.zip').archive, 'test.zip')
-        self.assertEqual(TarExtractor().extension(), '.tar')
-        self.assertEqual(TarGzipExtractor().extension(), '.tar.gz')
-        self.assertEqual(ZipExtractor().extension(), '.zip')
+        self.assertEqual(Extractor("test.zip").archive, "test.zip")
+        self.assertEqual(TarExtractor().extension(), ".tar")
+        self.assertEqual(TarGzipExtractor().extension(), ".tar.gz")
+        self.assertEqual(ZipExtractor().extension(), ".zip")
         for i in [TarExtractor(), ZipExtractor(), ZipExtractor()]:
-            i.set_archive('/tmp/foo')
+            i.set_archive("/tmp/foo")
             self.assertEqual(i.archive.endswith(i.extension()), True)
 
     def test_SourceProcessor_helpers(self):  # noqa: N802
         """Test SourceProcessor helpers."""
-        with mock.patch.object(SourceProcessor,
-                               'create_cache_directories',
-                               new=mock_create_cache_directories):
+        with mock.patch.object(
+            SourceProcessor,
+            "create_cache_directories",
+            new=mock_create_cache_directories,
+        ):
             sp = SourceProcessor(sources={})
 
             self.assertEqual(
-                sp.sanitize_git_path('git@github.com:foo/bar.git'),
-                'git_github.com_foo_bar'
+                sp.sanitize_git_path("git@github.com:foo/bar.git"),
+                "git_github.com_foo_bar",
             )
             self.assertEqual(
-                sp.sanitize_uri_path('http://example.com/foo/bar.gz@1'),
-                'http___example.com_foo_bar.gz_1'
+                sp.sanitize_uri_path("http://example.com/foo/bar.gz@1"),
+                "http___example.com_foo_bar.gz_1",
             )
             self.assertEqual(
-                sp.sanitize_git_path('git@github.com:foo/bar.git', 'v1'),
-                'git_github.com_foo_bar-v1'
+                sp.sanitize_git_path("git@github.com:foo/bar.git", "v1"),
+                "git_github.com_foo_bar-v1",
             )
 
-            for i in [GitPackageSource({'branch': 'foo'}), {'branch': 'foo'}]:
+            for i in [GitPackageSource({"branch": "foo"}), {"branch": "foo"}]:
+                self.assertEqual(sp.determine_git_ls_remote_ref(i), "refs/heads/foo")
+            for i in [{"uri": "git@foo"}, {"tag": "foo"}, {"commit": "1234"}]:
                 self.assertEqual(
-                    sp.determine_git_ls_remote_ref(i),
-                    'refs/heads/foo'
-                )
-            for i in [{'uri': 'git@foo'}, {'tag': 'foo'}, {'commit': '1234'}]:
-                self.assertEqual(
-                    sp.determine_git_ls_remote_ref(GitPackageSource(i)),
-                    'HEAD'
-                )
-                self.assertEqual(
-                    sp.determine_git_ls_remote_ref(i),
-                    'HEAD'
+                    sp.determine_git_ls_remote_ref(GitPackageSource(i)), "HEAD"
                 )
+                self.assertEqual(sp.determine_git_ls_remote_ref(i), "HEAD")
 
             self.assertEqual(
-                sp.git_ls_remote('https://github.com/remind101/stacker.git',
-                                 'refs/heads/release-1.0'),
-                b'857b4834980e582874d70feef77bb064b60762d1'
+                sp.git_ls_remote(
+                    "https://github.com/remind101/stacker.git", "refs/heads/release-1.0"
+                ),
+                b"857b4834980e582874d70feef77bb064b60762d1",
             )
 
-            bad_configs = [{'uri': 'x',
-                            'commit': '1234',
-                            'tag': 'v1',
-                            'branch': 'x'},
-                           {'uri': 'x', 'commit': '1234', 'tag': 'v1'},
-                           {'uri': 'x', 'commit': '1234', 'branch': 'x'},
-                           {'uri': 'x', 'tag': 'v1', 'branch': 'x'},
-                           {'uri': 'x', 'commit': '1234', 'branch': 'x'}]
+            bad_configs = [
+                {"uri": "x", "commit": "1234", "tag": "v1", "branch": "x"},
+                {"uri": "x", "commit": "1234", "tag": "v1"},
+                {"uri": "x", "commit": "1234", "branch": "x"},
+                {"uri": "x", "tag": "v1", "branch": "x"},
+                {"uri": "x", "commit": "1234", "branch": "x"},
+            ]
             for i in bad_configs:
                 with self.assertRaises(ImportError):
                     sp.determine_git_ref(GitPackageSource(i))
@@ -239,28 +234,32 @@ Outputs:
 
             self.assertEqual(
                 sp.determine_git_ref(
-                    GitPackageSource({'uri': 'https://github.com/remind101/'
-                                             'stacker.git',
-                                      'branch': 'release-1.0'})),
-                '857b4834980e582874d70feef77bb064b60762d1'
+                    GitPackageSource(
+                        {
+                            "uri": "https://github.com/remind101/" "stacker.git",
+                            "branch": "release-1.0",
+                        }
+                    )
+                ),
+                "857b4834980e582874d70feef77bb064b60762d1",
             )
             self.assertEqual(
                 sp.determine_git_ref(
-                    GitPackageSource({'uri': 'git@foo', 'commit': '1234'})),
-                '1234'
+                    GitPackageSource({"uri": "git@foo", "commit": "1234"})
+                ),
+                "1234",
             )
             self.assertEqual(
-                sp.determine_git_ref({'uri': 'git@foo', 'commit': '1234'}),
-                '1234'
+                sp.determine_git_ref({"uri": "git@foo", "commit": "1234"}), "1234"
             )
             self.assertEqual(
                 sp.determine_git_ref(
-                    GitPackageSource({'uri': 'git@foo', 'tag': 'v1.0.0'})),
-                'v1.0.0'
+                    GitPackageSource({"uri": "git@foo", "tag": "v1.0.0"})
+                ),
+                "v1.0.0",
             )
             self.assertEqual(
-                sp.determine_git_ref({'uri': 'git@foo', 'tag': 'v1.0.0'}),
-                'v1.0.0'
+                sp.determine_git_ref({"uri": "git@foo", "tag": "v1.0.0"}), "v1.0.0"
             )
 
 
